@@ -106,6 +106,8 @@ def _is_dir(a, *p):
 def _join_path(a, *p):
     if p and p[0] is not None:
         p = [str(_p) for _p in p]
+        if a is None:
+            return os.path.join(*p)
         return os.path.join(a, *p)
     else:
         return a
